@@ -16,11 +16,12 @@ class MobileNetV2(nn.Module):
     with open(str(Path(__file__).parent / 'schema' / 'mobilenet_v2_config.json')) as f:
         schema = json.load(f)
 
-    def __init__(self, config: MobileNetV2Config, batch_norm_2d: Type[nn.BatchNorm2d]):
+    def __init__(self, config: MobileNetV2Config):
         super().__init__()
         t = config.expansion_ratio
         input_size = config.input_size
         width_multiple = config.width_multiple
+        batch_norm_2d: Type[nn.BatchNorm2d] = torch_model_loader.load_default_batch_norm_2d()
 
         block_settings = [
             # t, c, n, s
@@ -65,6 +66,7 @@ class MobileNetV2(nn.Module):
         blocks.append(self.conv_bn_relu(in_channels, last_channels, kernel=1, stride=1, batch_norm_2d=batch_norm_2d))
         blocks.append(GlobalPooling())
         blocks.append(Flatten())
+        blocks.append(nn.Dropout(config.dropout_ratio))
         blocks.append(nn.Linear(last_channels, config.feature_dim))
 
         self.blocks = nn.Sequential(*blocks)
@@ -96,7 +98,6 @@ class MobileNetV2(nn.Module):
                 m.bias.data.zero_()
 
     @classmethod
-    def factory(cls, config: dict = None, **kwargs):
+    def factory(cls, config: dict = None):
         jsonschema.validate(config or {}, cls.schema)
-        batch_norm_2d = kwargs.get('batch_norm_2d', nn.BatchNorm2d)
-        return cls(config=MobileNetV2Config(values=config), batch_norm_2d=batch_norm_2d)
+        return cls(config=MobileNetV2Config(values=config))
