@@ -12,7 +12,7 @@ from .layers import Flatten, GlobalPooling
 
 
 class Bottleneck(nn.Module):
-    def __init__(self, in_channels: int, out_channels: int, stride: int, batch_norm_2d):
+    def __init__(self, in_channels: int, out_channels: int, stride: int, batch_norm_2d: Type[nn.BatchNorm2d]):
         super().__init__()
 
         mid_channels = out_channels // 4
@@ -46,8 +46,9 @@ class ResNet(nn.Module):
     with open(str(Path(__file__).parent / 'schema' / 'resnet_config.json')) as f:
         schema = json.load(f)
 
-    def __init__(self, config: ResNetConfig, batch_norm_2d: Type[nn.BatchNorm2d]):
+    def __init__(self, config: ResNetConfig):
         super().__init__()
+        batch_norm_2d: Type[nn.BatchNorm2d] = torch_model_loader.load_default_batch_norm_2d()
 
         in_channels = 64
         blocks = [
@@ -83,7 +84,6 @@ class ResNet(nn.Module):
         return self.blocks(x)
 
     @classmethod
-    def factory(cls, config: dict = None, **kwargs):
+    def factory(cls, config: dict = None):
         jsonschema.validate(config or {}, cls.schema)
-        batch_norm_2d = kwargs.get('batch_norm_2d', nn.BatchNorm2d)
-        return cls(config=ResNetConfig(values=config), batch_norm_2d=batch_norm_2d)
+        return cls(config=ResNetConfig(values=config))
